// OptionsPage.aspx.cs
// A listing of programming languages,
// choice is stored in pages Session object.

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

namespace Sessions
{
    /// <summary>
    /// page contains language options in a RadioButtonList
    /// will use a session variable to store user's choice
    /// </summary>
    public partial class OptionsPage : System.Web.UI.Page
    {
        // event handler for Load event
        protected void Page_Load(
           object sender, System.EventArgs e)
        {
            // if page is loaded due to postback, load session
            // information, hide language options from user
            if (IsPostBack)
            {
                // display components that contain session information
                welcomeLabel.Visible = true;
                languageLink.Visible = true;
                recommendationsLink.Visible = true;

                // hide components
                submitButton.Visible = false;
                promptLabel.Visible = false;
                languageList.Visible = false;

                // set labels to display Session information
                if (languageList.SelectedItem != null)
                    welcomeLabel.Text +=
                       languageList.SelectedItem.ToString() + ".";
                else
                    welcomeLabel.Text += "no language.";
            } // end if

            idLabel.Text = Session.LCID.ToString() ;
            timeoutLabel.Text = Session.Timeout.ToString() ;
            newSessionLabel.Text = Session.IsNewSession ? "nieuwe sessie" : "geen nieuwe sessie";

        } // end method Page_Load

        // when user clicks Submit button,
        // store user's choice in session object
        protected void submitButton_Click(
           object sender, System.EventArgs e)
        {
            if (languageList.SelectedItem != null)
            {
                // get applicationvariable that contains book recommendations
                Dictionary<String, String> books = (Dictionary<String, String>)Application["books"];
                string language =
                   languageList.SelectedItem.ToString();
                string ISBN = books[language];

                // store in session as name-value pair
                // name is language chosen, value is
                // ISBN number for corresponding book
                Session.Add(language, ISBN);

            } // end if

        } // end method submitBotton_Click

    } // end class OptionsPage

} // end namespace Sessions